/**
 * @file
 * VuoList_VuoDmxColorMap C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoDmxColorMap_H
#define VuoList_VuoDmxColorMap_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoDmxColorMap VuoList_VuoDmxColorMap
 * A list of @ref VuoDmxColorMap elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoDmxColorMap_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoDmxColorMap elements.
 */
typedef const struct VuoList_VuoDmxColorMap_struct { void *l; } * VuoList_VuoDmxColorMap;
/// @}
#endif

/**
 * Creates a new list of @ref VuoDmxColorMap elements.
 */
VuoList_VuoDmxColorMap VuoListCreate_VuoDmxColorMap(void);

/**
 * Makes a shallow copy of `list` — its items are retained (not copied) by the new list.
 */
VuoList_VuoDmxColorMap VuoListCopy_VuoDmxColorMap(const VuoList_VuoDmxColorMap list);

/**
 * Returns the @ref VuoDmxColorMap at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoDmxColorMap VuoListGetValue_VuoDmxColorMap(const VuoList_VuoDmxColorMap list, const unsigned long index);

/**
 * Changes the @ref VuoDmxColorMap at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValue_VuoDmxColorMap(const VuoList_VuoDmxColorMap list, const VuoDmxColorMap value, const unsigned long index);

/**
 * Inserts the `VuoDmxColorMap` immediately before `index`.
 * Index values start at 1.
 * Inserting at index 0 prepends the value to the list.
 * Inserting at an index beyond the last value in the list appends the value to the list.
 */
void VuoListInsertValue_VuoDmxColorMap(const VuoList_VuoDmxColorMap list, const VuoDmxColorMap value, const unsigned long index);

/**
 * Prepends @c value to @c list.
 */
void VuoListPrependValue_VuoDmxColorMap(VuoList_VuoDmxColorMap list, const VuoDmxColorMap value);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoDmxColorMap(VuoList_VuoDmxColorMap list, const VuoDmxColorMap value);

/**
 * Swaps the value at `indexA` with the value at `indexB`.
 */
void VuoListExchangeValues_VuoDmxColorMap(VuoList_VuoDmxColorMap list, const unsigned long indexA, const unsigned long indexB);

/**
 * Generates a random permutation of `list`.
 *
 * `chaos` ranges from 0 to 1.  When `chaos` is 1, a full Fisher–Yates shuffle is performed.  When less than 1, fewer iterations are performed.
 */
void VuoListShuffle_VuoDmxColorMap(VuoList_VuoDmxColorMap list, const double chaos);

/**
 * Reverses the order of the items in `list`.
 */
void VuoListReverse_VuoDmxColorMap(VuoList_VuoDmxColorMap list);

/**
 * Removes items from the list except those in the range specified by `startIndex` and `itemCount`.
 */
void VuoListCut_VuoDmxColorMap(VuoList_VuoDmxColorMap list, const signed long startIndex, const unsigned long itemCount);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoDmxColorMap(VuoList_VuoDmxColorMap list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoDmxColorMap(VuoList_VuoDmxColorMap list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoDmxColorMap(VuoList_VuoDmxColorMap list);

/**
 * Removes the `VuoDmxColorMap` at `index`.
 * Index values start at 1.
 * Attempting to remove index 0 or an index beyond the last value in the list has no effect.
 */
void VuoListRemoveValue_VuoDmxColorMap(VuoList_VuoDmxColorMap list, const unsigned long index);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoDmxColorMap(const VuoList_VuoDmxColorMap list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoDmxColorMap VuoList_VuoDmxColorMap_makeFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoDmxColorMap_getJson(const VuoList_VuoDmxColorMap value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoDmxColorMap_getSummary(const VuoList_VuoDmxColorMap value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoDmxColorMap VuoList_VuoDmxColorMap_makeFromString(const char *str);
char * VuoList_VuoDmxColorMap_getString(const VuoList_VuoDmxColorMap value);
/// @}

/**
 * @}
 */

#endif
