/**
 * @file
 * VuoList_VuoRenderedLayers C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoRenderedLayers_H
#define VuoList_VuoRenderedLayers_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoRenderedLayers VuoList_VuoRenderedLayers
 * A list of @ref VuoRenderedLayers elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoRenderedLayers_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoRenderedLayers elements.
 */
typedef const struct VuoList_VuoRenderedLayers_struct { void *l; } * VuoList_VuoRenderedLayers;
/// @}
#endif

/**
 * Creates a new list of @ref VuoRenderedLayers elements.
 */
VuoList_VuoRenderedLayers VuoListCreate_VuoRenderedLayers(void);

/**
 * Makes a shallow copy of `list` — its items are retained (not copied) by the new list.
 */
VuoList_VuoRenderedLayers VuoListCopy_VuoRenderedLayers(const VuoList_VuoRenderedLayers list);

/**
 * Returns the @ref VuoRenderedLayers at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoRenderedLayers VuoListGetValue_VuoRenderedLayers(const VuoList_VuoRenderedLayers list, const unsigned long index);

/**
 * Changes the @ref VuoRenderedLayers at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValue_VuoRenderedLayers(const VuoList_VuoRenderedLayers list, const VuoRenderedLayers value, const unsigned long index);

/**
 * Inserts the `VuoRenderedLayers` immediately before `index`.
 * Index values start at 1.
 * Inserting at index 0 prepends the value to the list.
 * Inserting at an index beyond the last value in the list appends the value to the list.
 */
void VuoListInsertValue_VuoRenderedLayers(const VuoList_VuoRenderedLayers list, const VuoRenderedLayers value, const unsigned long index);

/**
 * Prepends @c value to @c list.
 */
void VuoListPrependValue_VuoRenderedLayers(VuoList_VuoRenderedLayers list, const VuoRenderedLayers value);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoRenderedLayers(VuoList_VuoRenderedLayers list, const VuoRenderedLayers value);

/**
 * Swaps the value at `indexA` with the value at `indexB`.
 */
void VuoListExchangeValues_VuoRenderedLayers(VuoList_VuoRenderedLayers list, const unsigned long indexA, const unsigned long indexB);

/**
 * Generates a random permutation of `list`.
 *
 * `chaos` ranges from 0 to 1.  When `chaos` is 1, a full Fisher–Yates shuffle is performed.  When less than 1, fewer iterations are performed.
 */
void VuoListShuffle_VuoRenderedLayers(VuoList_VuoRenderedLayers list, const double chaos);

/**
 * Reverses the order of the items in `list`.
 */
void VuoListReverse_VuoRenderedLayers(VuoList_VuoRenderedLayers list);

/**
 * Removes items from the list except those in the range specified by `startIndex` and `itemCount`.
 */
void VuoListCut_VuoRenderedLayers(VuoList_VuoRenderedLayers list, const signed long startIndex, const unsigned long itemCount);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoRenderedLayers(VuoList_VuoRenderedLayers list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoRenderedLayers(VuoList_VuoRenderedLayers list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoRenderedLayers(VuoList_VuoRenderedLayers list);

/**
 * Removes the `VuoRenderedLayers` at `index`.
 * Index values start at 1.
 * Attempting to remove index 0 or an index beyond the last value in the list has no effect.
 */
void VuoListRemoveValue_VuoRenderedLayers(VuoList_VuoRenderedLayers list, const unsigned long index);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoRenderedLayers(const VuoList_VuoRenderedLayers list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoRenderedLayers VuoList_VuoRenderedLayers_makeFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoRenderedLayers_getJson(const VuoList_VuoRenderedLayers value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoRenderedLayers_getSummary(const VuoList_VuoRenderedLayers value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoRenderedLayers VuoList_VuoRenderedLayers_makeFromString(const char *str);
char * VuoList_VuoRenderedLayers_getString(const VuoList_VuoRenderedLayers value);
/// @}

/**
 * @}
 */

#endif
